@@ -280,7 +280,6 @@ apxServiceSetNames(APXHANDLE hService,
 
 BOOL
 apxServiceSetOptions(APXHANDLE hService,
-    LPCWSTR lpDependencies,
     DWORD dwServiceType,
     DWORD dwStartType,
     BOOL bDelayedStart,
@@ -306,27 +305,18 @@ apxServiceSetOptions(APXHANDLE hService,
         return FALSE;
     }
 
-    /* Add the mandatory dependencies */
-    if (lpDependencies) {
-        lpDependencies = apxMultiSzCombine(NULL, lpDependencies,
-                                           L"Tcpip\0Afd\0", NULL);
-    } else {
-        lpDependencies = L"Tcpip\0Afd\0";
-    }
-
     if (!ChangeServiceConfig(lpService->hService, dwServiceType,
                                    dwStartType, dwErrorControl,
-                                   NULL, NULL, NULL,
-                                   lpDependencies,
-                                   NULL, NULL, NULL)) {
-        apxLogWrite(APXLOG_MARK_WARN "Can't set options for service: Failed to change the configuration parameters.");
+                                   NULL, NULL, NULL, NULL, NULL,
+                                   NULL, NULL)) {
+        apxLogWrite(APXLOG_MARK_WARN "Can't set options for service: Failed to changes the configuration parameters.");
     	return FALSE;
     }
 
     if (dwStartType == SERVICE_AUTO_START) {
     	sDelayedInfo.fDelayedAutostart = bDelayedStart;
         if (!ChangeServiceConfig2A(lpService->hService, SERVICE_CONFIG_DELAYED_AUTO_START_INFO, &sDelayedInfo)) {
-            apxLogWrite(APXLOG_MARK_WARN "Can't set options for service: Failed to change the optional configuration parameters.");
+            apxLogWrite(APXLOG_MARK_WARN "Can't set options for service: Failed to changes the optional configuration parameters.");
             return FALSE;
         }
     }
@@ -575,7 +565,7 @@ apxServiceControl(APXHANDLE hService, DWORD dwControl, UINT uMsg,
                 break;
         }
     }
-    /* signal that we are done with controlling the service */
+    /* signal that we are done with controling the service */
     if (fnControlCallback)
         (*fnControlCallback)(lpCbData, uMsg, (WPARAM)3, (LPARAM)0);
     /* Check if we are in the desired state */
@@ -613,7 +603,7 @@ apxServiceControl(APXHANDLE hService, DWORD dwControl, UINT uMsg,
     return FALSE;
 }
 
-/* Wait one second and check that the service has stopped, returns TRUE if stopped FALSE otherwise */
+/* Wait one second and check that the service has stopped, returns TRUE if stopped FASE otherwise */
 BOOL
 apxServiceCheckStop(APXHANDLE hService)
 {
@@ -722,7 +712,6 @@ apxServiceInstall(APXHANDLE hService, LPCWSTR szServiceName,
 
     if (IS_INVALID_HANDLE(lpService->hService)) {
         apxLogWrite(APXLOG_MARK_SYSERR);
-        SetLastError(0);
         return FALSE;
     }
     else {
